notifyListenerTarget abstract method

void notifyListenerTarget(
  1. BaseNotifier notifier
)

Only for ElementRebuildable. Noop for others. Notifies that a new BaseNotifier is being listened. This should be called within a build method so it can unwatch old notifiers in the next microtask.

Implementation

void notifyListenerTarget(BaseNotifier notifier);