RebuildableNotifier<T, R> mixin
A notifier that can be rebuilt. In other words: The provider build lambda can be called again without the notifier being disposed.
T is the state type.
R is the return type of _builder.
- Implemented types
- Mixin applications
Properties
- customDebugLabel → String?
-
Override this to provide a custom debug label.
no setterinherited
- debugLabel → String
-
A label to be used in debug messages and
by the
RefenaTracingPage.no setterinherited -
dependencies
→ Set<
BaseNotifier> -
A collection of notifiers that this notifier depends on.
finalinherited
-
dependents
→ Set<
BaseNotifier> -
A collection of notifiers that depend on this notifier.
They will be disposed when this notifier is disposed.
finalinherited
- disposed → bool
-
Whether this notifier is disposed.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isWidget → bool
-
Whether this Rebuildable is an
ElementRebuildable. This is a workaround for the fact thatElementRebuildableis in refena_flutter so we cannot refer it from here.no setteroverride -
provider
→ BaseProvider<
BaseNotifier< ?T> , T> -
The provider that created this notifier.
This is only available after the initialization.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state ↔ T
-
Gets the current state.
getter/setter pairinherited
Methods
-
describeState(
T state) → String -
Override this to provide a customized description of the state.
This is used by the built-in observers for improved logging.
inherited
-
dispose(
) → void - This is called on Ref.dispose. You can override this method to dispose resources.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListenerTarget(
BaseNotifier notifier) → void -
Only for
ElementRebuildable. Noop for others. Notifies that a newBaseNotifieris being listened. This should be called within a build method so it can unwatch old notifiers in the next microtask.override -
onDisposeWidget(
) → void -
Only for
ElementRebuildable. Noop for others. Allows for further cleanup logic.override -
postInit(
) → void -
Override this to provide a custom post initialization.
The initial state is already set at this point.
inherited
-
rebuild(
ChangeEvent? changeEvent, RebuildEvent? rebuildEvent) → void -
Schedules a rebuild in the next microtask.
override
-
rebuildImmediately(
LabeledReference debugOrigin) → R - Rebuilds the notifier immediately.
-
toString(
) → String -
A string representation of this object.
inherited
-
updateShouldNotify(
T prev, T next) → bool -
Override this if you want to a different kind of equality.
inherited
Operators
-
operator ==(
Object other) → bool -
Subclasses should not override this method.
It is used internally by
dependenciesanddependents.inherited